@@ -22,9 +22,10 @@ contrast_models <- function(x, list_1 = NULL, list_2 = NULL,
     list_1 <- combos[1, ]
     list_2 <- combos[2, ]
   } else {
-    if (length(list_1) != length(list_2))
-      stop("`list_1` and `list_2` should be the same length.",
-           call. = FALSE)
+    if (length(list_1) != length(list_2)) {
+      rlang::abort("`list_1` and `list_2` should be the same length."
+      )
+    }
   }
 
   models <- purrr::map2(list_1, list_2, make_df, id_vals = x$ids)
@@ -88,23 +89,30 @@ summary.posterior_diff <- function(object, prob = 0.90, size = 0, ...) {
     dplyr::do(postint.data.frame(., prob = prob))
   post_stats <- object %>%
     dplyr::group_by(contrast) %>%
-    dplyr::summarise(probability = mean(posterior > 0),
-                     mean = mean(posterior)) %>%
+    dplyr::summarise(
+      probability = mean(posterior > 0),
+      mean = mean(posterior)
+    ) %>%
     dplyr::full_join(post_int, by = c("contrast"))
-  if(size != 0) {
+  if (size != 0) {
     rope_stats <- object %>%
       dplyr::group_by(contrast) %>%
-      dplyr::summarise(size = size,
-                       pract_neg = mean(posterior < -size),
-                       pract_equiv = mean(posterior >= -size & posterior <= size),
-                       pract_pos = mean(posterior > size))
-  } else
+      dplyr::summarise(
+        size = size,
+        pract_neg = mean(posterior < -size),
+        pract_equiv = mean(posterior >= -size & posterior <= size),
+        pract_pos = mean(posterior > size)
+      )
+  } else {
     rope_stats <- object %>%
-    dplyr::group_by(contrast) %>%
-    dplyr::summarise(size = size,
-                     pract_neg = na_dbl,
-                     pract_equiv = na_dbl,
-                     pract_pos = na_dbl)
+      dplyr::group_by(contrast) %>%
+      dplyr::summarise(
+        size = size,
+        pract_neg = na_dbl,
+        pract_equiv = na_dbl,
+        pract_pos = na_dbl
+      )
+  }
   dplyr::full_join(post_stats, rope_stats, by = c("contrast"))
 }
 
@@ -125,21 +133,20 @@ summary.posterior_diff <- function(object, prob = 0.90, size = 0, ...) {
 #' data(ex_objects)
 #' library(ggplot2)
 #' autoplot(contrast_samples)
-#'
 #' @export
 autoplot.posterior_diff <-
-  function (object, size = 0, ...) {
+  function(object, size = 0, ...) {
     object <- as.data.frame(object)
     out <-
       ggplot2::ggplot(object, ggplot2::aes(x = difference)) +
       ggplot2::geom_line(stat = "density", ...) +
       ggplot2::ylab("Posterior Probability")
     if (length(unique(paste0(object$model_1, object$model_2))) > 1) {
-      out <- out  + ggplot2::facet_grid(model_2 ~ model_1)
+      out <- out + ggplot2::facet_grid(model_2 ~ model_1)
     }
     if (size != 0) {
       out <- out +
-      ggplot2::geom_vline(xintercept = c(-size, size), lty = 2, alpha = .5)
+        ggplot2::geom_vline(xintercept = c(-size, size), lty = 2, alpha = .5)
     }
     out
   }
@@ -155,21 +162,23 @@ make_df <- function(a, b, id_vals = NULL) {
 make_diffs <- function(spec, obj, trans, seed) {
   res_1 <- posterior_epred(
     obj,
-    newdata = spec[1,],
+    newdata = spec[1, ],
     seed = seed,
     re.form = NA
   )
-  res_1 <- trans$inv(res_1[,1])
+  res_1 <- trans$inv(res_1[, 1])
   res_2 <- posterior_epred(
     obj,
-    newdata = spec[2,],
+    newdata = spec[2, ],
     seed = seed,
     re.form = NA
   )
-  res_2 <- trans$inv(res_2[,1])
-  res <- data.frame(difference = res_1 - res_2,
-                    model_1 = as.character(spec$model[1]),
-                    model_2 = as.character(spec$model[2]),
-                    stringsAsFactors = FALSE)
+  res_2 <- trans$inv(res_2[, 1])
+  res <- data.frame(
+    difference = res_1 - res_2,
+    model_1 = as.character(spec$model[1]),
+    model_2 = as.character(spec$model[2]),
+    stringsAsFactors = FALSE
+  )
   res
 }
