@@ -1,12 +1,14 @@
 check_trans <- function(x) {
   trans_msg <- "`transform` should have two functions: 'func' and 'inv'"
-  if(length(x) != 2) {
-    stop(trans_msg, call. = FALSE)
+  if (length(x) != 2) {
+    rlang::abort(trans_msg)
   } else {
-    if(!all(sort(names(x)) == c("func", "inv")))
-      stop(trans_msg, call. = FALSE)
-    if(!all(is.function(transform)))
-      stop(trans_msg, call. = FALSE)
+    if (!all(sort(names(x)) == c("func", "inv"))) {
+      rlang::abort(trans_msg)
+    }
+    if (!all(is.function(transform))) {
+      rlang::abort(trans_msg)
+    }
   }
   invisible(x)
 }
@@ -21,4 +23,3 @@ get_id_vals <- function(x) {
   id_vars <- grep("(^id$)|(^id[1-9]$)", names(x), value = TRUE)
   map(x[, id_vars, drop = FALSE], function(x) unique(as.character(x)))
 }
-
